package org.eco.common.hadoop.config;

import lombok.extern.slf4j.Slf4j;
import org.apache.hadoop.conf.Configuration;
import org.apache.hadoop.fs.FileSystem;
import org.eco.common.hadoop.config.properties.HadoopProperties;
import org.eco.common.hadoop.hdfs.HadoopClient;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.autoconfigure.AutoConfiguration;
import org.springframework.boot.autoconfigure.condition.ConditionalOnBean;
import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
import org.springframework.boot.context.properties.EnableConfigurationProperties;
import org.springframework.context.annotation.Bean;

import java.net.URI;

/**
 * @Description: HadoopConfig
 * @Author: GaoKun Wang
 * @Date: 2024/9/19
 */
@AutoConfiguration
@EnableConfigurationProperties(HadoopProperties.class)
@ConditionalOnProperty(value = "hadoop.enabled", havingValue = "true")
@Slf4j
public class HadoopConfig {

    @Autowired
    private HadoopProperties properties;

    @Bean
    public FileSystem fileSystem() {
        System.setProperty("hadoop.home.dir", "D:\\tools\\hadoop\\hadoop-3.3.0");
//        System.setProperty("HADOOP_USER_NAME", "root");
        Configuration configuration = new Configuration();
        configuration.set("dfs.replication", properties.getReplication());
        configuration.set("fs.defaultFS", properties.getNameNode());
        configuration.set("mapred.job.tracker", properties.getNameNode());
        FileSystem fs = null;
        try {
            URI uri = new URI(properties.getDirectoryPath().trim());
            fs = FileSystem.get(uri, configuration, properties.getUserName());
        } catch (Exception e) {
            log.error("", e);
        }
        return fs;
    }

    @Bean
    @ConditionalOnBean(FileSystem.class)
    public HadoopClient hadoopClient(FileSystem fs, HadoopProperties hadoopProperties) {
        return new HadoopClient(fs, hadoopProperties);
    }
}
